---
title: <span class="badge object-type-scalar"></span> MilliOhm
---
# <span class="badge object-type-scalar"></span> MilliOhm

Energy: Milliohm (mΩ)

## Definition

```python
# Energy: Milliohm (mΩ)
MilliOhm: typing.Literal["mohm"] = "mohm"
```
